@@ -321,10 +321,10 @@ std::vector<ValueTestParam> UnboundRelationshipTestCases() {
 std::vector<ValueTestParam> PathTestCases() {
   std::vector<ValueTestParam> inputs;
   {
-    mg_node *nodes[] = {mg_node_make(1, 0, NULL, mg_map_make_empty(0)),
-                        mg_node_make(2, 0, NULL, mg_map_make_empty(0)),
-                        mg_node_make(3, 0, NULL, mg_map_make_empty(0)),
-                        mg_node_make(4, 0, NULL, mg_map_make_empty(0))};
+    mg_node *nodes[] = {mg_node_make(1, 0, nullptr, mg_map_make_empty(0)),
+                        mg_node_make(2, 0, nullptr, mg_map_make_empty(0)),
+                        mg_node_make(3, 0, nullptr, mg_map_make_empty(0)),
+                        mg_node_make(4, 0, nullptr, mg_map_make_empty(0))};
     mg_unbound_relationship *relationships[] = {
         mg_unbound_relationship_make(12, mg_string_make("EDGE"),
                                      mg_map_make_empty(0)),
